@@ -1,7 +1,8 @@
 import sys
+from typing import Tuple
 
+from je_auto_control.utils.exception.exception_tags import linux_import_error
 from je_auto_control.utils.exception.exceptions import AutoControlException
-from je_auto_control.utils.exception.exception_tag import linux_import_error
 
 if sys.platform not in ["linux", "linux2"]:
     raise AutoControlException(linux_import_error)
@@ -9,7 +10,7 @@ if sys.platform not in ["linux", "linux2"]:
 from je_auto_control.linux_with_x11.core.utils.x11_linux_display import display
 
 
-def size():
+def size() -> Tuple[int, int]:
     """
     get screen size
     """
